==> smartgwt-5.1p.zip: com/smartgwt/logicalstructure/widgets/StretchImgButtonLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class StretchImgButtonLogicalStructure extends StretchImgLogicalStructure {
    public String actionType;
    public String align;
    public String autoFit;
    public String baseStyle;
    public String capSize;
    public String hiliteAccessKey;
    public String icon;
    public String iconAlign;
    public String iconHeight;
    public String iconOrientation;
    public String iconSize;
    public String iconSpacing;
    public String iconWidth;
    public String labelBreadthPad;
    public String labelHPad;
    public String labelLengthPad;
    public String labelSkinImgDir;
    public String labelVPad;
    public String radioGroup;
    public String selected;
    public String showClippedTitleOnHover;
    public String showDisabled;
    public String showDisabledIcon;
    public String showDown;
    public String showDownIcon;
    public String showFocused;
    public String showFocusedIcon;
    public String showRollOver;
    public String showRollOverIcon;
    public String showSelectedIcon;
    public String showTitle;
    public String src;
    public String state;
    public String title;
    public String titleStyle;
    public String valign;
    public String vertical;
    public String wrap;
}

==> smartgwt-12.1p.zip: com/smartgwt/logicalstructure/widgets/StretchImgButtonLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class StretchImgButtonLogicalStructure extends StretchImgLogicalStructure {
    public String actionType;
    public String align;
    public String autoFit;
    public String baseStyle;
    public String capSize;
    public String heightAsString;
    public String hiliteAccessKey;
    public String icon;
    public String iconAlign;
    public String iconHeight;
    public String iconOrientation;
    public String iconSize;
    public String iconSpacing;
    public String iconWidth;
    public String labelBreadthPad;
    public String labelHPad;
    public String labelLengthPad;
    public String labelSkinImgDir;
    public String labelVPad;
    public String radioGroup;
    public String showClippedTitleOnHover;
    public String showDisabled;
    public String showDisabledIcon;
    public String showDown;
    public String showDownIcon;
    public String showFocused;
    public String showFocusedIcon;
    public String showRollOver;
    public String showRollOverIcon;
    public String showSelectedIcon;
    public String showTitle;
    public String src;
    public String state;
    public String title;
    public String titleStyle;
    public String valign;
    public String vertical;
    public String widthAsString;
    public String wrap;
}
